# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-09-01 06:18
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sample', '0002_howitworks'),
    ]

    operations = [
        migrations.AddField(
            model_name='product',
            name='product_type',
            field=models.CharField(choices=[('s', 'Sellable'), ('r', 'Rentable')], default='s', max_length=1),
        ),
    ]
